summaryrefslogtreecommitdiffstats
path: root/src/dabOutput/dabOutputFile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/dabOutput/dabOutputFile.cpp')
-rw-r--r--src/dabOutput/dabOutputFile.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/dabOutput/dabOutputFile.cpp b/src/dabOutput/dabOutputFile.cpp
index b8e9e70..d798daa 100644
--- a/src/dabOutput/dabOutputFile.cpp
+++ b/src/dabOutput/dabOutputFile.cpp
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
switch (this->type_) {
case ETI_FILE_TYPE_FRAMED:
// Writting nb of frames at beginning of file
if (lseek(this->file_, 0, SEEK_SET) == -1) goto FILE_WRITE_ERROR;
if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
// Writting nb frame length at end of file
if (lseek(this->file_, 0, SEEK_END) == -1) goto FILE_WRITE_ERROR;
if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
@@ -62,7 +62,7 @@ int DabOutputFile::Write(void* buffer, int size)
if (write(this->file_, buffer, size) == -1) goto FILE_WRITE_ERROR;
break;
case ETI_FILE_TYPE_STREAMED:
// Writting nb frame length at end of file
if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
// Appending data
@@ -85,7 +85,7 @@ int DabOutputFile::Write(void* buffer, int size)
return size;
FILE_WRITE_ERROR:
- perror("Error while writting to file");
+ perror("Error while writing to file");
return -1;
}
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
switch (this->type_) {
case ETI_FILE_TYPE_FRAMED:
- // Writting nb of frames at beginning of file
+ // Writing nb of frames at beginning of file
if (lseek(this->file_, 0, SEEK_SET) == -1) goto FILE_WRITE_ERROR;
if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
if (lseek(this->file_, 0, SEEK_SET) == -1) goto FILE_WRITE_ERROR;
if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
- // Writting nb frame length at end of file
+ // Writing nb frame length at end of file
if (lseek(this->file_, 0, SEEK_END) == -1) goto FILE_WRITE_ERROR;
if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
@@ -62,7 +62,7 @@ int DabOutputFile::Write(void* buffer, int size)
break;
case ETI_FILE_TYPE_STREAMED:
- // Writting nb frame length at end of file
+ // Writing nb frame length at end of file
if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
// Appending data